@@ -1,3 +1,5 @@
+// -*- Mode: c++; c-basic-offset: 4; tab-width: 4; -*-
+
 // Test only makes sure we can use different argv types for the
 // parser. Don't run, just compile.
 
@@ -6,7 +8,7 @@
 using namespace TCLAP;
 int main()
 {
-	char *argv5[] = {"Foo", 0};
+        char *argv5[] = {(char*)"Foo", 0};
 	const char *argv6[] = {"Foo", 0};
 	const char * const argv7[] = {"Foo", 0};
 	char **argv1 = argv5;
