@@ -1,3 +1,5 @@
+// -*- Mode: c++; c-basic-offset: 4; tab-width: 4; -*-
+
 #include "tclap/CmdLine.h"
 #include <iterator>
 #include <algorithm>
@@ -33,7 +35,7 @@ struct Vect : public TCLAP::StringLikeTrait {
 
     std::ostream& print(std::ostream &os) const
         {
-            std::copy(v, v + LEN, std::ostream_iterator<T>(os, " "));
+            std::copy(v, v + LEN, std::ostream_iterator<T>(os, ", "));
             return os;
         }
 
