@@ -2,4 +2,4 @@
 # this tests whether all required args are listed as
 # missing when no arguments are specified
 # failure  
-`dirname $0`/simple-test.sh `basename $0 .sh` test11 -v "1 2 3"
+./test_wrapper $srcdir/test64.out ../examples/test11 '-v "1 2 3"'
